@@ -10,7 +10,7 @@ test_that("accepts correct inputs", {
 
 test_that("warnings or errors are issued", {
   # Takes too much time and add load on servers
-  skip_on_cran()
+  skip_if_offline()
 
   # Should correctly identify format type
   out <- check_version("https://cn.dataone.org/cn/v2/resolve/urn:uuid:a2834e3e-f453-4c2b-8343-99477662b570")
