@@ -13,7 +13,8 @@ test_that("accepts correct inputs", {
 # EDI package test(s) ----
 test_that("accepts EDI data package", {
   # Takes too much time and add load on servers
-  skip_on_cran()
+  skip_if_offline()
+
   output <- download_d1_data_pkg(
     meta_obj = 'doi:10.6073/pasta/9f2f89e48f9e943f7125d1a335d96eb0',
     path = tempdir()
@@ -25,7 +26,8 @@ test_that("accepts EDI data package", {
 # Arctic Data Center test(s) ----
 test_that("accepts Arctic Data Center data package", {
   # Takes too much time and add load on servers
-  skip_on_cran()
+  skip_if_offline()
+
   output <- download_d1_data_pkg(
     meta_obj = 'doi:10.18739/A2B27PS44',
     path = tempdir()
